@@ -126,16 +126,18 @@ class LeapBinder:
             raise Exception('None preprocess_handler')
 
         for state, preprocess_response in preprocess_result.items():
+            if preprocess_response.length is None or preprocess_response.length <= 0:
+                raise Exception('Invalid dataset length')
             if unlabeled_preprocess_handler is not None and state == DataStateEnum.unlabeled:
                 unlabeled_preprocess_handler.data_length = preprocess_response.length
             else:
                 state_type = DataStateType(state.name)
                 preprocess_handler.data_length[state_type] = preprocess_response.length
 
-    def preprocess_result(self) -> Dict[DataStateEnum, PreprocessResponse]:
+    def get_preprocess_result(self) -> Dict[DataStateEnum, PreprocessResponse]:
         preprocess = self.setup_container.preprocess
-        # TODO: add caching of subset result
-        assert preprocess is not None
+        if preprocess is None:
+            raise Exception("Please make sure you call the leap_binder.set_preprocess method")
         preprocess_results = preprocess.function()
         preprocess_result_dict = {
             DataStateEnum(i): preprocess_result
@@ -196,6 +198,6 @@ class LeapBinder:
                 self.check_handler(preprocess_response, test_result, dataset_base_handler)
 
     def check(self) -> None:
-        preprocess_result = self.preprocess_result()
+        preprocess_result = self.get_preprocess_result()
         self.check_preprocess(preprocess_result)
         self.check_handlers(preprocess_result)
